<?php
/*
Plugin Name: Pending Comments Highlighter
Contributors: mahone
Tags: comments, pending, background, text color
Requires at least: 4.1
Tested up to: 6.7
Requires PHP: 5.4
Plugin URI: http://www.olcsoweboldal.hu/blog/2011/01/10/pending-comments-highlighter/
Description: This plugin allows you to customize the background and text color of pending comments in the WordPress admin.
Author: Adam Szucs
Stable tag: 2.1
Version: 2.1
Author URI: http://olcsoweboldal.hu
License: GPL-2.0+
License URI: http://www.gnu.org/licenses/gpl-2.0.txt
*/

// Beállítások regisztrálása biztonságos sanitizálással
function pch_register_settings() {
    register_setting(
        'pch_settings_group',
        'pch_pending_comment_bg_color',
        array(
            'type'              => 'string',
            'sanitize_callback' => 'sanitize_hex_color',
            'default'           => '#dd9933',
        )
    );

    register_setting(
        'pch_settings_group',
        'pch_pending_comment_text_color',
        array(
            'type'              => 'string',
            'sanitize_callback' => 'sanitize_hex_color',
            'default'           => '#000000',
        )
    );

    register_setting(
        'pch_settings_group',
        'pch_pending_comment_link_color',
        array(
            'type'              => 'string',
            'sanitize_callback' => 'sanitize_hex_color',
            'default'           => '#ffffff',
        )
    );
}
add_action('admin_init', 'pch_register_settings');

// Admin menüpont hozzáadása
function pch_add_admin_menu() {
    add_submenu_page(
        'edit-comments.php',
        'Pending Comments Settings',
        'Pending Comments Highlighter setting',
        'manage_options',
        'pending-comments-settings',
        'pch_settings_page'
    );
}
add_action('admin_menu', 'pch_add_admin_menu');

// Beállítások oldal
function pch_settings_page() {
    ?>
    <div class="wrap">
        <h1>Pending Comments Highlighter Settings</h1>

        <?php if (isset($_GET['settings-updated']) && $_GET['settings-updated'] == 'true') : ?>
            <div id="message" class="updated notice is-dismissible">
                <p><?php esc_html_e('The colours of pending comments have been successfully changed.', 'pending-comments-highlighter'); ?></p>
            </div>
        <?php endif; ?>

        <form method="post" action="options.php">
            <?php
            settings_fields('pch_settings_group');
            do_settings_sections('pch_settings_group');
            ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Pending Comment Background Color:</th>
                    <td>
                        <input type="text" name="pch_pending_comment_bg_color"
                               value="<?php echo esc_attr(get_option('pch_pending_comment_bg_color', '#DD823B')); ?>"
                               class="color-picker"/>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Pending Comment Text Color:</th>
                    <td>
                        <input type="text" name="pch_pending_comment_text_color"
                               value="<?php echo esc_attr(get_option('pch_pending_comment_text_color', '#FFFFFF')); ?>"
                               class="color-picker"/>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Pending Comment Link Color:</th>
                    <td>
                        <input type="text" name="pch_pending_comment_link_color"
                               value="<?php echo esc_attr(get_option('pch_pending_comment_link_color', '#000000')); ?>"
                               class="color-picker"/>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <script>
        jQuery(document).ready(function ($) {
            $('.color-picker').wpColorPicker();
        });
    </script>
    <?php
}

// Admin CSS beillesztése a kiválasztott színekkel
function pch_pending_comments_highlighter() {
    $bg_color = get_option('pch_pending_comment_bg_color', '#DD823B');
    $text_color = get_option('pch_pending_comment_text_color', '#FFFFFF');
    $link_color = get_option('pch_pending_comment_link_color', '#000000');

    if (!empty($bg_color) && !empty($text_color) && !empty($link_color)) {
        echo '<style>
            tr.unapproved th, tr.unapproved td { background-color: ' . esc_html($bg_color) . ' !important; }
            tr.unapproved p, tr.unapproved strong { color: ' . esc_html($text_color) . ' !important; }
            tr.unapproved a, tr.unapproved strong { color: ' . esc_html($link_color) . ' !important; }
        </style>';
    }
}
add_action('admin_head', 'pch_pending_comments_highlighter');

// WordPress színválasztó betöltése
function pch_enqueue_color_picker($hook_suffix) {
    if ('edit-comments.php' !== $hook_suffix && 'comments_page_pending-comments-settings' !== $hook_suffix) {
        return;
    }
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('wp-color-picker');
}
add_action('admin_enqueue_scripts', 'pch_enqueue_color_picker');
